%define major   20
%define libname %mklibname louis %{major}
%define devname %mklibname louis -d

Name:           liblouis
Version:        3.32.0
Release:        %mkrel 1
Summary:        Braille translation and back-translation library
Group:          System/Libraries
# LGPL-2.1-or-later: the project as a whole
# LGPL-2.0-or-later: parts of gnulib
# - gnulib/_Noreturn.h
# - gnulib/arg-nonnull.h
# - gnulib/c++defs.h
# - gnulib/warn-on-use.h
License:        LGPL-2.1-or-later AND LGPL-2.0-or-later
URL:            https://liblouis.io/
Source0:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  hardlink
BuildRequires:  help2man
BuildRequires:  texinfo
BuildRequires:  texlive
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(yaml-0.1)

Provides:       bundled(gnulib)

%description
Liblouis is an open-source braille translator and back-translator named in
honor of Louis Braille. It features support for computer and literary braille,
supports contracted and uncontracted translation for many languages and has
support for hyphenation. New languages can easily be added through tables that
support a rule- or dictionary based approach. Liblouis also supports math
braille (Nemeth and Marburg).

Liblouis has features to support screen-reading programs. This has led to its
use in two open-source screen readers, NVDA and Orca. It is also used in some
commercial assistive technology applications for example by ViewPlus.

Liblouis is based on the translation routines in the BRLTTY screen reader for
Linux. It has, however, gone far beyond these routines.

%package -n %{libname}
Summary:        Braille translation and back-translation library
Group:          System/Libraries
Requires:       %{name}-tables >= %{version}-%{release}

%description -n %{libname}
Liblouis is an open-source braille translator and back-translator named in
honor of Louis Braille. It features support for computer and literary braille,
supports contracted and uncontracted translation for many languages and has
support for hyphenation. New languages can easily be added through tables that
support a rule- or dictionary based approach. Liblouis also supports math
braille (Nemeth and Marburg).

Liblouis has features to support screen-reading programs. This has led to its
use in two open-source screen readers, NVDA and Orca. It is also used in some
commercial assistive technology applications for example by ViewPlus.

Liblouis is based on the translation routines in the BRLTTY screen reader for
Linux. It has, however, gone far beyond these routines.


%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        tables
Summary:        Data tables
Group:          System/Internationalization
# LGPL-2.1-or-later: most of the tables
# LGPL-3.0-or-later:
# - tables/Es-Es-G0.utb
# - tables/et-g0.utb
# - tables/is-chardefs6.cti
# - tables/is-chardefs8.cti
# - tables/pt-pt-g2.ctb
# - tables/sr-chardefs.cti
# - tables/sr-g1.ctb
License:        LGPL-2.1-or-later AND LGPL-3.0-or-later
BuildArch:      noarch

%description    tables
Data tables for liblouis, containing attributes and dot patterns.


%package        utils
Summary:        Command-line utilities to test %{name}
Group:          System/Internationalization
# GPL-3.0-or-later: the source code in tools
# LGPL-2.0-or-later AND LGPL-2.1-or-later: tools/gnulib
# LGPL-3.0-or-later: tools/gnulib/version-etc.{c,h}
# LGPL-3.0-or-later OR GPL-2.0-or-later:
# - tools/gnulib/unistr/u16-mbtoucr.c
# - tools/gnulib/unistr/u16-to-u8.c
License:        GPL-3.0-or-later AND LGPL-3.0-or-later AND LGPL-2.1-or-later AND LGPL-2.0-or-later AND (LGPL-3.0-or-later OR GPL-2.0-or-later)

%description    utils
Six test programs are provided as part of the liblouis package. They
are intended for testing liblouis and for debugging tables. None of
them is suitable for braille transcription.


%package -n python3-louis
Summary:        Python 3 language bindings for %{name}
Group:          Development/Python
BuildArch:      noarch

%description -n python3-louis
This package provides Python 3 language bindings for %{name}.


%package doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch
# See doc/liblouis.texi
License:        LGPL-3.0-or-later

%description doc
This package provides the documentation for liblouis.


%prep
%autosetup -p1

chmod 664 tables/*

%generate_buildrequires
cd python
%pyproject_buildrequires

%build
%configure --disable-static --enable-ucs4
%make_build

# build python binding
pushd python
%pyproject_wheel
popd

%install
%make_install
%make_install -C doc

rm -f %{buildroot}%{_infodir}/dir
rm -rf %{buildroot}%{_bindir}/lou_maketable*
rm -rf %{buildroot}%{_defaultdocdir}/%{name}/

# Install internal.h for MuseScore
install -pm 0644 liblouis/internal.h %{buildroot}%{_includedir}/%{name}

# Hardlink table files with identical content
hardlink -t %{buildroot}%{_datadir}/%{name}/tables/

# install python binding
pushd python
%pyproject_install
%pyproject_save_files louis
popd

%check
LD_LIBRARY_PATH=%{buildroot}%{_libdir} make check

%files -n %{libname}
%doc README AUTHORS NEWS ChangeLog TODO
%license COPYING.LESSER
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n %{devname}
%doc HACKING
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_infodir}/%{name}.info*

%files tables
%{_datadir}/%{name}/

%files utils
%license COPYING
%{_bindir}/lou_*
%{_mandir}/man1/lou_*.1*

%files -n python3-louis -f %{pyproject_files}

%files doc
%doc doc/%{name}.{html,txt,pdf}


%changelog
* Fri Feb 07 2025 daviddavid <daviddavid> 3.32.0-1.mga10
+ Revision: 2145896
- new version: 3.32.0

* Sat Sep 14 2024 daviddavid <daviddavid> 3.31.0-1.mga10
+ Revision: 2096005
- new version: 3.31.0

* Wed Jun 12 2024 daviddavid <daviddavid> 3.30.0-1.mga10
+ Revision: 2072832
- new version: 3.30.0

* Wed Mar 20 2024 daviddavid <daviddavid> 3.29.0-1.mga10
+ Revision: 2050964
- initial package liblouis

